==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/RunAsUserStrategyOptionsFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RunAsUserStrategyOptionsFluent<A extends RunAsUserStrategyOptionsFluent<A>> extends BaseFluent<A>{
  public RunAsUserStrategyOptionsFluent() {
  }
  public RunAsUserStrategyOptionsFluent(RunAsUserStrategyOptions instance) {
    instance = (instance != null ? instance : new RunAsUserStrategyOptions());

    if (instance != null) {
      this.withType(instance.getType());
      this.withUid(instance.getUid());
      this.withUidRangeMax(instance.getUidRangeMax());
      this.withUidRangeMin(instance.getUidRangeMin());
      this.withType(instance.getType());
      this.withUid(instance.getUid());
      this.withUidRangeMax(instance.getUidRangeMax());
      this.withUidRangeMin(instance.getUidRangeMin());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String type;
  private Long uid;
  private Long uidRangeMax;
  private Long uidRangeMin;
  private Map<String,Object> additionalProperties;
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public boolean hasType() {
    return this.type != null;
  }
  public Long getUid() {
    return this.uid;
  }
  public A withUid(Long uid) {
    this.uid=uid; return (A) this;
  }
  public boolean hasUid() {
    return this.uid != null;
  }
  public Long getUidRangeMax() {
    return this.uidRangeMax;
  }
  public A withUidRangeMax(Long uidRangeMax) {
    this.uidRangeMax=uidRangeMax; return (A) this;
  }
  public boolean hasUidRangeMax() {
    return this.uidRangeMax != null;
  }
  public Long getUidRangeMin() {
    return this.uidRangeMin;
  }
  public A withUidRangeMin(Long uidRangeMin) {
    this.uidRangeMin=uidRangeMin; return (A) this;
  }
  public boolean hasUidRangeMin() {
    return this.uidRangeMin != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RunAsUserStrategyOptionsFluent that = (RunAsUserStrategyOptionsFluent) o;
    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(uid, that.uid)) return false;

    if (!java.util.Objects.equals(uidRangeMax, that.uidRangeMax)) return false;

    if (!java.util.Objects.equals(uidRangeMin, that.uidRangeMin)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(type,  uid,  uidRangeMax,  uidRangeMin,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid + ","); }
    if (uidRangeMax != null) { sb.append("uidRangeMax:"); sb.append(uidRangeMax + ","); }
    if (uidRangeMin != null) { sb.append("uidRangeMin:"); sb.append(uidRangeMin + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/RunAsUserStrategyOptionsFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RunAsUserStrategyOptionsFluent<A extends RunAsUserStrategyOptionsFluent<A>> extends BaseFluent<A>{
  public RunAsUserStrategyOptionsFluent() {
  }
  
  public RunAsUserStrategyOptionsFluent(RunAsUserStrategyOptions instance) {
    this.copyInstance(instance);
  }
  private String type;
  private Long uid;
  private Long uidRangeMax;
  private Long uidRangeMin;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(RunAsUserStrategyOptions instance) {
    instance = (instance != null ? instance : new RunAsUserStrategyOptions());
  
    if (instance != null) {
        this.withType(instance.getType());
        this.withUid(instance.getUid());
        this.withUidRangeMax(instance.getUidRangeMax());
        this.withUidRangeMin(instance.getUidRangeMin());
        this.withType(instance.getType());
        this.withUid(instance.getUid());
        this.withUidRangeMax(instance.getUidRangeMax());
        this.withUidRangeMin(instance.getUidRangeMin());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public Long getUid() {
    return this.uid;
  }
  
  public A withUid(Long uid) {
    this.uid=uid; return (A) this;
  }
  
  public boolean hasUid() {
    return this.uid != null;
  }
  
  public Long getUidRangeMax() {
    return this.uidRangeMax;
  }
  
  public A withUidRangeMax(Long uidRangeMax) {
    this.uidRangeMax=uidRangeMax; return (A) this;
  }
  
  public boolean hasUidRangeMax() {
    return this.uidRangeMax != null;
  }
  
  public Long getUidRangeMin() {
    return this.uidRangeMin;
  }
  
  public A withUidRangeMin(Long uidRangeMin) {
    this.uidRangeMin=uidRangeMin; return (A) this;
  }
  
  public boolean hasUidRangeMin() {
    return this.uidRangeMin != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RunAsUserStrategyOptionsFluent that = (RunAsUserStrategyOptionsFluent) o;
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(uid, that.uid)) return false;
  
    if (!java.util.Objects.equals(uidRangeMax, that.uidRangeMax)) return false;
  
    if (!java.util.Objects.equals(uidRangeMin, that.uidRangeMin)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(type,  uid,  uidRangeMax,  uidRangeMin,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid + ","); }
    if (uidRangeMax != null) { sb.append("uidRangeMax:"); sb.append(uidRangeMax + ","); }
    if (uidRangeMin != null) { sb.append("uidRangeMin:"); sb.append(uidRangeMin + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
